@@ -182,8 +182,6 @@ glibtop_get_proc_open_files_s (glibtop *server, glibtop_proc_open_files *buf,	pi
 	struct dirent *direntry;
 	DIR *dir;
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_OPEN_FILES, 0);
-
 	memset (buf, 0, sizeof (glibtop_proc_open_files));
 
 	sprintf (fn, "/proc/%d/fd", pid);
@@ -195,7 +193,6 @@ glibtop_get_proc_open_files_s (glibtop *server, glibtop_proc_open_files *buf,	pi
 
 	while((direntry = readdir(dir))) {
 		char tgt [BUFSIZ];
-		int rv;
 		glibtop_open_files_entry entry = {0};
 
 		if(direntry->d_name[0] == '.')
@@ -204,7 +201,7 @@ glibtop_get_proc_open_files_s (glibtop *server, glibtop_proc_open_files *buf,	pi
 		g_snprintf(fn, sizeof fn, "/proc/%d/fd/%s",
 			   pid, direntry->d_name);
 
-		if (!safe_readlink(fn, tgt, tgt))
+		if (!safe_readlink(fn, tgt, sizeof tgt))
 			continue;
 
 		entry.fd = atoi(direntry->d_name);
